#!/bin/bash

. `dirname $0`/../../scripts/CONFIG.sh

print_header "Common"
parse_opts "$@"

if [ "$clean" = 1 ]; then
   # ??? What should we do here ?
   echo ""
   exit 0
fi

run_and_exit "make -C .."
$valgrind ../obj/test_htables
$valgrind ../obj/test_arrays
$valgrind ../obj/test_strings
$valgrind ../obj/test_trie

echo_with_status 1 ""
